nxp-pac

Crates

git

Versions

mcxa577

Flavors

Modectrl

Struct Modectrl 

#[repr(transparent)]
pub struct Modectrl(pub u16);
MODE Control

Tuple Fields

0: u16

Implementations

Source

impl Modectrl

pub const fn cmd(&self) -> Cmd

Set back to NONE when mode controller has entered the selected mode

pub const fn set_cmd(&mut self, val: Cmd)

Set back to NONE when mode controller has entered the selected mode